.. IPTVTools documentation master file, created by
   sphinx-quickstart on Sat Jan 11 12:07:20 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to IPTVTools's documentation!
=====================================

.. toctree::
   :maxdepth: 2

   installation
   scripts
   parameters

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
